package com.xx.merchanthbh.ui.home;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.os.Message;
import android.provider.Settings;
import android.util.Log;
import android.view.KeyEvent;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.Observer;

import com.xx.merchanthbh.BR;
import com.xx.merchanthbh.R;
import com.xx.merchanthbh.data.http.requst.HomeRequest;
import com.xx.merchanthbh.data.http.requst.LogOffRequest;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.databinding.ActivityHomeBinding;
import com.xx.merchanthbh.ui.home.HomeFragment;
import com.tbruyelle.rxpermissions3.RxPermissions;
import com.xx.merchanthbh.ui.home.HomeViewModel;
import com.xx.merchanthbh.ui.huanbohai.HuanBoHaiFragment;
import com.xx.merchanthbh.ui.login.LoginActivity;
import com.xx.merchanthbh.ui.logoff.LogOffViewModel;
import com.xx.merchanthbh.ui.mine.MineFragment;
import com.google.android.material.bottomnavigation.BottomNavigationView;
import com.xx.xxviewlibrary.base.AppManager;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class HomeActivity extends BaseActivity<ActivityHomeBinding, HomeViewModel> {


    // 定义一个变量，来标识是否退出
    private static boolean isExit = false;

    Handler mHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            isExit = false;
        }
    };

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_home;

    }


    @Override
    public void onResume() {
        super.onResume();
        // 手动更新页面UI内容
        updateUI();
        // 检查版本
        viewModel.rxPermissions = new RxPermissions(this);

        // 检查版本
        viewModel.checkVersion(binding.getRoot().getRootView());


        // 安装新版本
        viewModel.openInstall.observe(this, new Observer<String>() {
            @Override
            public void onChanged(String s) {
                if ("1".equals(s)) {
                    checkPermission();
                }
            }
        });




    }

    private void checkPermission() {

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
            if (!Environment.isExternalStorageManager()) {
                // 弹出权限请求对话框
                showCommTextDialog(new RefuseDialogBean("申请的是授予管理所有文件的权限,用于更新最新安装包，可能会因为无权限导致不能使用完整功能" + ",是否同意", "同意", "拒绝"),
                        new CommTextDialog.onAcceptCallBack() {
                            @Override
                            public void acceptBack() {

                                Intent intent = new Intent(Settings.ACTION_MANAGE_APP_ALL_FILES_ACCESS_PERMISSION);
                                intent.setData(Uri.parse("package:" + getPackageName()));
                                startActivityForResult(intent, 1024);
                            }

                            @Override
                            public void refuseBack() {

                            }
                        });
            }}
    }


    /*更新页面,注销标志位做判断*/
    private void updateUI() {
        if (StaticData.logOffData == 1) {
            finish();
            startActivity(LoginActivity.class);
        }else {
        }
    }

    @Override
    public void initData() {
         super.initData();
        // 获取Intent对象
        Intent intent = getIntent();

        // 从Intent中获取传递的额外信息
        if (intent != null) {
            String logFlag = intent.getStringExtra("logFlag");
            if (logFlag != null) {
            }else {
                // 获取SharedPreferences实例
                SharedPreferences sharedPreferences = getSharedPreferences("AppNamePreferences", Context.MODE_PRIVATE);

                // 从SharedPreferences中获取用户名和密码
                String username = sharedPreferences.getString("username", null);
                String password = sharedPreferences.getString("password", null);
                String token = sharedPreferences.getString("token", null);
                // 检查是否成功获取到用户名和密码
                if (username != null && password != null) {
                    Interceptor_TOKEN = token;
                    viewModel.getLogin(username,password);
                    // 获取协议
                    viewModel.getProtocols();
                }else {
                    startActivity(LoginActivity.class);
                    finish();
                }
            }
        }


        // 初始化底部导航栏
        BottomNavigationView bottomNavigationView = findViewById(R.id.bottom_navigation_view);
        bottomNavigationView.setOnNavigationItemSelectedListener(navItemSelectedListener);

        // 显示默认的 Fragment
        getSupportFragmentManager().beginTransaction().replace(R.id.fragment_container, new HomeFragment()).commit();


    }
    @Override
    public int initVariableId() {
        return BR.homeViewModel;
    }
    @Override
    public void onStart() {
        super.onStart();

    }



    @Override
    public void onPointerCaptureChanged(boolean hasCapture) {
        super.onPointerCaptureChanged(hasCapture);
    }


    private final BottomNavigationView.OnNavigationItemSelectedListener navItemSelectedListener = item -> {
        Fragment selectedFragment = null;

        // 根据选项 ID 创建相应的 Fragment
        if (item.getItemId() == R.id.menu_home) {
            selectedFragment = new HomeFragment();
        } else if (item.getItemId() == R.id.menu_huanbohai) {
            selectedFragment = new HuanBoHaiFragment();
        }else if (item.getItemId() == R.id.menu_mine) {
            selectedFragment = new MineFragment();
        }


        // 替换当前显示的 Fragment
        // 确保选择项不能为空
        assert selectedFragment != null;
        getSupportFragmentManager().beginTransaction().replace(R.id.fragment_container, selectedFragment).commit();
        return true;
    };


    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            exit();
            return false;
        }
        return super.onKeyDown(keyCode, event);
    }


    private void exit() {
        showCommTextDialog(new RefuseDialogBean("是否确认退出APP？", "确定", "取消"), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void acceptBack() {
                Intent intent = new Intent(Intent.ACTION_MAIN);
                intent.addCategory(Intent.CATEGORY_HOME);
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                startActivity(intent);
            }

            @Override
            public void refuseBack() {

            }
        });

    }

    @Override
    protected void onStop() {
        super.onStop();

    }
    @Override
    public HomeViewModel initViewModel() {
        HomeRequest lm = new HomeRequest();
        return new HomeViewModel(getApplication(), lm);
    }


    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        if (requestCode==1024){
            Uri packageURI = Uri.parse("package:" + getPackageName());
            Intent intent = new Intent(Settings.ACTION_MANAGE_UNKNOWN_APP_SOURCES, packageURI);
            startActivityForResult(intent, 1002);
        }
    }
}